@@ -2,7 +2,7 @@ package Fibble::Bar;
 
 use strict;
 use warnings;
-use Bogus::PreReq;
+use CPANPLUS 99999;
 use vars qw($VERSION);
 
 $VERSION = '0.01';
